@@ -1,6 +1,7 @@
 from viset.caltech import Caltech101
 from viset.dataset import Viset
-import cv
+from viset.show import imshow
+
 
 if __name__ == '__main__':
   # Create a new viset
@@ -13,13 +14,13 @@ if __name__ == '__main__':
   db = Viset(dbfile)
   for (im,annotation) in db.read(n_skip=100):
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    cv.ShowImage('Caltech101', cv.fromarray(im))
-    cv.WaitKey(100)
+    imshow(im)
+    sleep(0.2)
 
   for (im,annotation) in db.read(category=['airplanes','Faces'], n_skip=10):
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
-    cv.ShowImage('Caltech101', cv.fromarray(im))
-    cv.WaitKey(1000)
+    imshow(im)
+    sleep(0.2)
 
   # Cleanup cached data (optional)
   print 'Deleting all cached data in "' + db.cachedir + '"'  
