@@ -1,6 +1,6 @@
 from viset.imagenet import ImageNetFall2011
 from viset.dataset import Viset
-import cv
+from viset.show import imshow
 
 if __name__ == '__main__':
   # Create a new viset
@@ -14,6 +14,7 @@ if __name__ == '__main__':
   for (im,annotation) in db.read(n_skip=100):
     print 'Image=' + str(annotation['id_img']) + ' Category=' + annotation['category']
     if im is not None:
-      cv.ShowImage('ImageNet', cv.fromarray(im))
-      cv.WaitKey(100)
+      imshow(im)
+      sleep(0.2)
+
 
